class pyflames():

    def __init__(self):
        return None
    
    def flames(self,name1,name2):
        name1 =list("".join(str(x)for x in name1.replace(" ","")))
        name2 =list("".join(str(x)for x in name2.replace(" ","")))
        common = [x for x in name1 if x in name2]
        unique = set(common)
        d=0
        for x in unique:
            d = d + min(name1.count(x),name2.count(x))
        difference = (len(name1) + len(name2)) - d*2
        target = ["Friendship","Love","Affection","Marriage","Enemity","Sibling Love"]
        while len(target)>1:
            counter = ((difference%len(target))-1)
            if counter>=0:
                part1 = target[counter+1:]
                part2 = target[:counter]
                target = part1+part2
            else:
                target = target[:len(target)-1]
        return "The relationship that exists between both of you is "+target[0]+"."


import io
import os
import sys
import setuptools
from setuptools import find_packages, setup, Command

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
  name = 'pyflames',
  packages = ['pyflames'],
  version = '1.0',
  license='MIT',
  description = "Python library to compare two strings and return their relationship status as per Asia's famous FLAMES Game",
  long_description=long_description,
  long_description_content_type="text/markdown",
  author = 'SHYAM SALIL',
  author_email = 'shyamsalil1993@gmail.com',
  url = 'https://github.com/shyams1993/pyflames',
  py_modules=['mypackage'],
  entry_points={'console_scripts': ['mycli=mymodule:cli'],},
  keywords = ['INTERESTING'],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.4',  
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6'
  ],
  python_requires='>=3.1',
)